@@ -189,12 +189,12 @@ class SnsToLambda(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="snsTopic")
     def sns_topic(self) -> aws_cdk.aws_sns.Topic:
         return typing.cast(aws_cdk.aws_sns.Topic, jsii.get(self, "snsTopic"))
@@ -228,9 +228,9 @@ class SnsToLambdaProps:
         :summary: The properties for the SnsToLambda class.
         '''
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+            lambda_function_props = FunctionProps(**lambda_function_props)
         if isinstance(topic_props, dict):
-            topic_props = aws_cdk.aws_sns.TopicProps(**topic_props)
+            topic_props = TopicProps(**topic_props)
         if __debug__:
             type_hints = typing.get_type_hints(SnsToLambdaProps.__init__)
             check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
